<?php
session_start();
include 'db_connect.php';

// Prüfen, ob die Datei install.php existiert
if (file_exists(__DIR__ . '/install.php')) {
    header('Location: install.php');
    exit();
}

// Eingaben bereinigen, um XSS-Angriffe zu verhindern
function sanitize($data) {
    return htmlspecialchars(trim($data), ENT_QUOTES, 'UTF-8');
}

// Funktion zum Erstellen eines sicheren Tokens
function generateToken($length = 64) {
    return bin2hex(random_bytes($length));
}

// Überprüfung auf Brute-Force-Angriffe
function checkBruteForce($pdo, $ip, $limit = 5, $interval = 10) {
    $stmt = $pdo->prepare('SELECT COUNT(*) FROM failed_logins WHERE ip_address = ? AND attempted_at > NOW() - INTERVAL ? MINUTE');
    $stmt->execute([$ip, $interval]);
    return $stmt->fetchColumn() >= $limit;
}

// IP-Adresse des Benutzers
$ip = $_SERVER['REMOTE_ADDR'];

// CSRF-Token erzeugen
if ($_SERVER['REQUEST_METHOD'] == 'GET') {
    $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
}

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // CSRF-Token validieren
    if (!hash_equals($_SESSION['csrf_token'], $_POST['csrf_token'])) {
        die('Ungültiges Token.');
    }

    $benutzername = sanitize($_POST['benutzername']);
    $passwort = $_POST['passwort'];
    $remember = isset($_POST['remember']);

    // Brute-Force-Schutz
    if (checkBruteForce($pdo, $ip)) {
        die('Zu viele fehlgeschlagene Anmeldeversuche. Bitte versuchen Sie es später erneut.');
    }

    // Verwendung von Prepared Statements zur Vermeidung von SQL-Injection
    $stmt = $pdo->prepare('SELECT id, benutzername, passwort, rolle FROM mitarbeiter WHERE benutzername = :benutzername');
    $stmt->bindParam(':benutzername', $benutzername, PDO::PARAM_STR);
    $stmt->execute();
    $user = $stmt->fetch();

    // Überprüfung des Passworts
    if ($user && password_verify($passwort, $user['passwort'])) {
        // Session-ID regenerieren, um Session-Fixation zu verhindern
        session_regenerate_id(true);
        $_SESSION['user_id'] = $user['id'];
        $_SESSION['benutzername'] = $user['benutzername'];
        $_SESSION['rolle'] = $user['rolle'];

        // **URL der Webseite in der Session speichern**
        $_SESSION['site_url'] = $_SERVER['HTTP_HOST'];

        // Sitzungs-ID in der Datenbank speichern
        $sessionId = session_id();
        $stmt = $pdo->prepare('UPDATE mitarbeiter SET session_id = ? WHERE id = ?');
        $stmt->execute([$sessionId, $user['id']]);

        if ($remember) {
            // Token generieren
            $token = generateToken();
            $hashedToken = password_hash($token, PASSWORD_DEFAULT);

            // Token in der Datenbank speichern
            $stmt = $pdo->prepare('INSERT INTO auth_tokens (user_id, token_hash, expires_at) VALUES (:user_id, :token_hash, DATE_ADD(NOW(), INTERVAL 30 DAY))');
            $stmt->execute([
                ':user_id' => $user['id'],
                ':token_hash' => $hashedToken
            ]);

            // Token im Cookie speichern
            setcookie('remember_me', $token, [
                'expires' => time() + (86400 * 30), // 30 Tage
                'path' => '/',
                'secure' => true, // Nur über HTTPS senden
                'httponly' => true,
                'samesite' => 'Strict'
            ]);
        }

        // Erfolgreiche Anmeldung protokollieren
        $stmt = $pdo->prepare('INSERT INTO login_logs (user_id, ip_address, login_time, success) VALUES (?, ?, NOW(), ?)');
        $stmt->execute([$user['id'], $ip, true]);

        header('Location: dashboard.php');
        exit();
    } else {
        // Fehlerhafte Anmeldung protokollieren
        $stmt = $pdo->prepare('INSERT INTO failed_logins (ip_address, attempted_at) VALUES (?, NOW())');
        $stmt->execute([$ip]);

        $error = "Ungültige Anmeldedaten.";
    }
}

// Überprüfung des "Eingeloggt bleiben"-Tokens
if (!isset($_SESSION['user_id']) && isset($_COOKIE['remember_me'])) {
    $token = $_COOKIE['remember_me'];

    // Token in der Datenbank suchen
    $stmt = $pdo->prepare('SELECT user_id, token_hash FROM auth_tokens WHERE expires_at > NOW()');
    $stmt->execute();
    $tokens = $stmt->fetchAll();

    foreach ($tokens as $row) {
        if (password_verify($token, $row['token_hash'])) {
            // Benutzerinformationen abrufen
            $stmtUser = $pdo->prepare('SELECT id, benutzername, rolle FROM mitarbeiter WHERE id = :id');
            $stmtUser->execute([':id' => $row['user_id']]);
            $user = $stmtUser->fetch();

            if ($user) {
                // Sitzung wiederherstellen
                session_regenerate_id(true);
                $_SESSION['user_id'] = $user['id'];
                $_SESSION['benutzername'] = $user['benutzername'];
                $_SESSION['rolle'] = $user['rolle'];

                // **URL der Webseite in der Session speichern**
                $_SESSION['site_url'] = $_SERVER['HTTP_HOST'];

                header('Location: dashboard.php');
                exit();
            }
        }
    }

    // Ungültiges Token, Cookie löschen
    setcookie('remember_me', '', time() - 3600, '/');
}
?>
<!DOCTYPE html>
<html lang="de">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, viewport-fit=cover">
    <title>Anmeldung - Lagerverwaltung</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;500;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css">
    <style>
        body {
            background: linear-gradient(to right, #ffffff, #7a7272);
            font-family: 'Roboto', sans-serif;
            height: 100vh;
            display: flex;
            justify-content: center;
            align-items: center;
            margin: 0;
        }

        .login-container {
            background: white;
            display: flex;
            border-radius: 15px;
            overflow: hidden;
            max-width: 900px;
            width: 100%;
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.2);
        }

        .login-info {
            background: linear-gradient(to top, #ff7e5f, #feb47b);
            color: white;
            padding: 40px;
            flex: 1;
            display: flex;
            flex-direction: column;
            justify-content: center;
            text-align: left;
        }

        .login-info h1 {
            font-size: 2rem;
            margin-bottom: 1rem;
        }

        .login-info p {
            font-size: 1rem;
            line-height: 1.6;
        }

        .login-form {
            flex: 1;
            padding: 40px;
        }

        .login-form h3 {
            text-align: center;
            margin-bottom: 20px;
        }

        .form-control, .btn {
            border-radius: 25px;
        }

        .input-group-text {
            background-color: #f2f5f7;
            border-radius: 25px 0 0 25px;
        }

        .btn-primary {
            background: linear-gradient(to right, #ff7e5f, #feb47b);
            border: none;
        }

        .btn-primary:hover {
            background: linear-gradient(to right, #feb47b, #ff7e5f);
        }

        .forgot-password {
            text-align: right;
            font-size: 0.875rem;
            margin-top: 10px;
        }

        .forgot-password a {
            text-decoration: none;
            color: #ff7e5f;
        }

        .forgot-password a:hover {
            text-decoration: underline;
        }

        .form-check {
            margin-top: 15px;
        }

        @media (max-width: 768px) {
            body, html {
                height: 100%;
                margin: 0;
                padding: 0;
                overflow: visible;
                position: relative;
                display: block;
            }

            .login-container {
                position: absolute;
                top: 50%;
                left: 50%;
                transform: translate(-50%, -50%);
                width: 90%;
                max-width: 400px;
                padding: 20px;
                background: white;
                border-radius: 10px;
                box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
                z-index: 1000;
            }

            .login-info {
                display: none;
            }

            .btn-primary {
                width: 100%;
            }

            .input-group {
                margin-bottom: 15px;
            }
        }
    </style>
</head>
<body>
    <div class="login-container">
        <div class="login-info">
            <h1>Willkommen</h1>
            <p>Verwalten Sie Ihr Lager effizient und einfach. Melden Sie sich an, um Zugang zu erhalten.</p>
        </div>
        <div class="login-form">
            <h3>Anmeldung</h3>
            <?php if (isset($error)): ?>
                <div class="alert alert-danger" role="alert">
                    <?php echo htmlspecialchars($error); ?>
                </div>
            <?php endif; ?>
            <form action="login.php" method="POST">
                <input type="hidden" name="csrf_token" value="<?php echo htmlspecialchars($_SESSION['csrf_token']); ?>">
                <div class="mb-3">
                    <div class="input-group">
                        <span class="input-group-text"><i class="bi bi-person-fill"></i></span>
                        <input type="text" class="form-control" id="benutzername" name="benutzername" placeholder="Benutzername" required>
                    </div>
                </div>
                <div class="mb-3">
                    <div class="input-group">
                        <span class="input-group-text"><i class="bi bi-lock-fill"></i></span>
                        <input type="password" class="form-control" id="passwort" name="passwort" placeholder="Passwort" required>
                    </div>
                </div>
                <div class="form-check">
                    <input type="checkbox" class="form-check-input" id="remember" name="remember">
                    <label class="form-check-label" for="remember">Eingeloggt bleiben</label>
                </div>
                <div class="forgot-password">
                    <a href="#">Passwort vergessen?</a>
                </div>
                <button type="submit" class="btn btn-primary btn-block mt-3">Anmelden</button>
            </form>
            <p class="text-center mt-4">Noch kein Konto? <a href="register.php" style="color: #ff7e5f;">Hier registrieren</a>.</p>
        </div>
    </div>
    <script>
        function adjustLoginFormPosition() {
            if (window.innerWidth <= 768) { // Nur bei mobiler Breite
                const loginContainer = document.querySelector('.login-container');
                const windowHeight = window.innerHeight;

                // Setze die Höhe des Containers auf die sichtbare Höhe
                loginContainer.style.position = 'absolute';
                loginContainer.style.top = `${windowHeight / 2}px`;
                loginContainer.style.transform = 'translate(-50%, -50%)';
                loginContainer.style.left = '50%';
            } else {
                // Setze Standardposition zurück
                const loginContainer = document.querySelector('.login-container');
                loginContainer.style.position = 'relative';
                loginContainer.style.top = 'unset';
                loginContainer.style.left = 'unset';
                loginContainer.style.transform = 'unset';
            }
        }

        // Rufe die Funktion beim Laden und bei Änderungen der Fenstergröße auf
        window.addEventListener('load', adjustLoginFormPosition);
        window.addEventListener('resize', adjustLoginFormPosition);
    </script>
</body>
</html>
